%bcond_with shared_libuv

%define major 12
%define minor 8
%define fix 1

%define node_prefix %{_libdir}/%{name}

Name: nodejs%{major}
Version: %{major}.%{minor}.%{fix}
Release: 1
License: MIT
Summary: Node.js JavaScript Runtime
Url: https://www.nodejs.org


BuildRequires: python2
BuildRequires: zlib-devel
BuildRequires: openssl-devel >= 1.1.1
%if %{with shared_libuv}
BuildRequires: libuv-devel
%endif

# Previous versions of OpenSSL 1.1 export memcpy/strcpy/etc due to -bexpall,
# but the GA version has a manual export list, so they are not exported.
# Due to order passed to the linker, node 10 used to link to these functions
# explicitly which causes load failures if we don't upgrade in lock-step.
Requires: libopenssl1_1 > 1.1.1-2

Requires: nodever

Source0: https://nodejs.org/dist/v%{major}.%{minor}.%{fix}/node-v%{major}.%{minor}.%{fix}.tar.gz

Patch0: nodejs%{major}-cmsg-space.patch
Patch1: nodejs%{major}-fswatch.patch
Patch2: nodejs%{major}-libuv.patch

%description
Node.js is a JavaScript runtime built on Chrome V8 JavaScript engine. Node.js
uses an event-driven, non-blocking I/O model that makes it lightweight and
efficient.

%prep
%setup -q -n node-v%{version}

%patch0 -p1
%patch1 -p1
%patch2 -p1

# Fix the wrong dependencies /bin/sh and /usr/bin/python
find . -type f | xargs perl -pi -e 's|/usr/bin/python|%{_bindir}/python2|g;s|#!/bin/sh|#!/QOpenSys/usr/bin/sh|g'

# Fix hardcoded node absolute path
# Yes, '-type f' is necessary as there's a directory named foo.js...
find . -type f -name "*.js" | xargs perl -pi -e 's|/usr/bin/env node|%{node_prefix}/bin/node|g'

%build

export CC=gcc
export CXX=g++

./configure \
  --prefix=%{node_prefix} \
  --dest-cpu=ppc64 \
  --without-node-snapshot \
  --shared-openssl \
  --shared-zlib \
  %{?with_shared_libuv:--shared-libuv} \
  # end

%make_build
# basic verification
./node -e "console.log(process.versions)"

%install

%make_install V=1 PORTABLE=1

%postun
if [ "$1" = "0" ] ; then
  ls -l /QOpenSys/pkgs/bin/node 2> /dev/null | grep %{node_prefix} >/dev/null
  if [ $? -eq 0 ]; then
    /QOpenSys/pkgs/bin/nodever auto &>/dev/null # set another available node effective
  fi
fi

%post
if [ ! -e "/QOpenSys/pkgs/bin/node" ] ; then
  ln -sf /QOpenSys/pkgs/lib/nodejs%{major}/bin/node /QOpenSys/pkgs/bin/node
fi
if [ ! -e "/QOpenSys/pkgs/bin/npm" ] ; then
  ln -sf /QOpenSys/pkgs/lib/nodejs%{major}/bin/npm /QOpenSys/pkgs/bin/npm
fi

%files
# Set the default owner to QSYS and group to *NONE
%defattr(-, qsys, *none)

%{node_prefix}

%changelog
* Tue Aug 20 2019 Xu Meng <mengxumx@cn.ibm.com>
- Upgrade to Node.js v12.8.1

* Wed Aug 14 2019 Xu Meng <mengxumx@cn.ibm.com>
- Upgrade to Node.js v12.7.0

* Tue Jul 9 2019 Xu Meng <mengxumx@cn.ibm.com>
- Upgrade to Node.js v12.5.0

* Tue May 7 2019 Xu Meng <mengxumx@cn.ibm.com>
- Upgrade to Node.js v12.1.0

* Wed Apr 24 2019 Kevin Adler <kadler@us.ibm.com> - 12.0.0
- Upgrade to Node.js 12

* Mon Mar 11 2019 - Xu Meng <mengxumx@cn.ibm.com>
- update to v10.15.3

* Thu Jan 17 2019 - Xu Meng <mengxumx@cn.ibm.com>
- call 'nodever auto' when uninstall

* Wed Jan 09 2019 - Xu Meng <mengxumx@cn.ibm.com>
- fix the EISDIR issue(https://github.com/nodejs/node/issues/25433)

* Fri Jan 04 2019 - Xu Meng <mengxumx@cn.ibm.com>
- update to v10.15.0

* Sun Dec 09 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v10.14.1

* Wed Nov 14 2018 - Kevin Adler <kadler@us.ibm.com>
- update OpenSSL to v1.1.1

* Mon Oct 08 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v10.11.0

* Thu Aug 23 2018 - Xu Meng <mengxumx@cn.ibm.com>
- make nodejs create the global links 

* Thu Aug 23 2018 - Xu Meng <mengxumx@cn.ibm.com>
- update to v10.9.0

* Mon Aug 20 2018 - Xu Meng <mengxumx@cn.ibm.com>
- use fs.watchFile() instead of fs.watch() by default

* Mon Aug 06 2018 - Xu Meng <mengxumx@cn.ibm.com>
- fix the uv_resident_set_memory issue to support yarn

* Mon May 14 2018 - Xu Meng <mengxumx@cn.ibm.com>
- nodejs version control(nodever) support

* Mon May 14 2018 - Xu Meng <mengxumx@cn.ibm.com>
- enable inspector

* Thu Apr 19 2018 - Xu Meng <mengxumx@cn.ibm.com>
- fix a definition issue
